# HTTPSecuritySettings

Configuration of an HTTP Application's security model.

## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**csp** | [**CSPSettings**](CSPSettings.md) |  | [optional] 
**cors** | [**CORSSettings**](CORSSettings.md) |  | [optional] 
**hsts** | [**HSTSSettings**](HSTSSettings.md) |  | [optional] 
**xss_protection** | [**XSSSettings**](XSSSettings.md) |  | [optional] 
**certificate_transparency** | [**CertificateTransparencySettings**](CertificateTransparencySettings.md) |  | [optional] 
**frame_options** | [**FrameOptionsSettings**](FrameOptionsSettings.md) |  | [optional] 
**content_type_options** | [**ContentTypeOptionsSettings**](ContentTypeOptionsSettings.md) |  | [optional] 
**permitted_cross_domain_policies** | [**PermittedCrossDomainPoliciesSettings**](PermittedCrossDomainPoliciesSettings.md) |  | [optional] 
**coep** | [**CrossOriginEmbedderPolicySettings**](CrossOriginEmbedderPolicySettings.md) |  | [optional] 
**coop** | [**CrossOriginOpenerPolicySettings**](CrossOriginOpenerPolicySettings.md) |  | [optional] 
**corp** | [**CrossOriginResourcePolicySettings**](CrossOriginResourcePolicySettings.md) |  | [optional] 
**referrer_policy** | [**ReferrerPolicySettings**](ReferrerPolicySettings.md) |  | [optional] 
**any string name** | **bool, date, datetime, dict, float, int, list, str, none_type** | any string name can be used but the value must be the correct type | [optional]

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


